@@ -20,7 +20,7 @@ C<PPIx::Regexp::Token::Assertion> has no descendants.
 This class represents one of the simple assertions; that is, those that
 are not defined via parentheses. This includes the zero-width assertions
 C<^>, C<$>, C<\b>, C<\B>, C<\A>, C<\Z>, C<\z> and C<\G>, as well as the
-positive look-behind assertion C<\K> added in Perl 5.010.
+positive look-behind assertion C<\K> added in Perl 5.009005.
 
 =head1 METHODS
 
@@ -36,9 +36,9 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-use PPIx::Regexp::Constant qw{ $COOKIE_CLASS $MINIMUM_PERL $TOKEN_LITERAL };
+use PPIx::Regexp::Constant qw{ COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL };
 
-our $VERSION = '0.008';
+our $VERSION = '0.021';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -46,12 +46,13 @@ our $VERSION = '0.008';
 {
 
     my %perl_version_introduced = (
-	'\\K' => '5.010',
+	'\\K' => '5.009005',
+	'\\z' => '5.005',
     );
 
     sub perl_version_introduced {
 	my ( $self ) = @_;
-	return $perl_version_introduced{$self->content()} || $MINIMUM_PERL;
+	return $perl_version_introduced{$self->content()} || MINIMUM_PERL;
     }
 
 }
@@ -72,8 +73,8 @@ sub __PPIX_TOKENIZER__regexp {
     my ( $class, $tokenizer, $character ) = @_;
 
     # Inside a character class, these are all literals.
-    my $make = $tokenizer->cookie( $COOKIE_CLASS ) ?
-	$TOKEN_LITERAL :
+    my $make = $tokenizer->cookie( COOKIE_CLASS ) ?
+	TOKEN_LITERAL :
 	__PACKAGE__;
 
     # '^' and '$'. Or at least '^'. See note above for '$'.
@@ -105,7 +106,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
