@@ -39,7 +39,7 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.015';
+our $VERSION = '0.021';
 
 {
 
@@ -49,6 +49,9 @@ our $VERSION = '0.015';
 	'\H'	=> '5.009005',	# Before this, parsed as 'H'
 	'\N'	=> '5.011',	# Before this, an error.
 	'\V'	=> '5.009005',	# Before this, parsed as 'V'
+	'\R'	=> '5.009005',
+	'\C'	=> '5.006',
+	'\X'	=> '5.006',
     );
 
     sub perl_version_introduced {
@@ -83,7 +86,7 @@ sub __PPIX_TOKENIZER__regexp {
 
     if ( my $accept = $tokenizer->find_regexp(
 	    qr{ \A \\ (?:
-		[wWsSdDvVhHXRN] |
+		[wWsSdDvVhHXRNC] |
 		[Pp] \{ \s* \^? [\w:=\s-]+ \}
 	    ) }smx
 	) ) {
@@ -118,7 +121,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
