@@ -41,9 +41,13 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use Carp qw{ confess };
 
-use PPIx::Regexp::Constant qw{ $RE_CAPTURE_NAME };
+use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME };
 
-our $VERSION = '0.008';
+our $VERSION = '0.021';
+
+use constant NAMED_CAPTURE =>
+    qr{ \A \\? \? (?: P? < ( @{[ RE_CAPTURE_NAME ]} ) \\? > |
+		\\? ' ( @{[ RE_CAPTURE_NAME ]} ) \\? ' ) }smxo;
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -60,18 +64,27 @@ sub name {
 }
 
 sub perl_version_introduced {
-    return '5.010';
+    return '5.009005';
 }
 
 sub __PPIX_TOKEN__post_make {
     my ( $self, $tokenizer ) = @_;
-    foreach my $name ( $tokenizer->capture() ) {
-	defined $name or next;
-	$self->{name} = $name;
-	return;
+    if ( $tokenizer ) {
+	foreach my $name ( $tokenizer->capture() ) {
+	    defined $name or next;
+	    $self->{name} = $name;
+	    return;
+	}
+    } else {
+	foreach my $name (
+	    $self->content() =~ m/ @{[ NAMED_CAPTURE ]} /smxo ) {
+	    defined $name or next;
+	    $self->{name} = $name;
+	    return;
+	}
     }
 
-    confess "Programming error - can not figure out capture name";
+    confess 'Programming error - can not figure out capture name';
 }
 
 sub __PPIX_TOKENIZER__regexp {
@@ -79,9 +92,7 @@ sub __PPIX_TOKENIZER__regexp {
 
     # The optional escapes are because any of the non-open-bracket
     # punctuation characters may be the expression delimiter.
-    if ( my $accept = $tokenizer->find_regexp(
-	    qr{ \A \\? \? (?: P? < ( $RE_CAPTURE_NAME ) \\? > |
-			\\? ' ( $RE_CAPTURE_NAME ) \\? ' ) }smx ) ) {
+    if ( my $accept = $tokenizer->find_regexp( NAMED_CAPTURE ) ) {
 	return $accept;
     }
 
@@ -103,7 +114,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
