@@ -1,4 +1,3 @@
-
 package PPIx::Regexp::Tokenizer;
 
 use strict;
@@ -7,12 +6,16 @@ use warnings;
 use base qw{ PPIx::Regexp::Support };
 
 use Carp qw{ confess };
-use Params::Util 0.25 qw{ _INSTANCE };
-use PPIx::Regexp::Constant qw{ $TOKEN_LITERAL $TOKEN_UNKNOWN };
+use PPIx::Regexp::Constant qw{
+    MINIMUM_PERL
+    TOKEN_LITERAL
+    TOKEN_UNKNOWN
+};
 use PPIx::Regexp::Token::Assertion		();
 use PPIx::Regexp::Token::Backreference		();
 use PPIx::Regexp::Token::Backtrack		();
 use PPIx::Regexp::Token::CharClass::POSIX	();
+use PPIx::Regexp::Token::CharClass::POSIX::Unknown	();
 use PPIx::Regexp::Token::CharClass::Simple	();
 use PPIx::Regexp::Token::Code			();
 use PPIx::Regexp::Token::Comment		();
@@ -36,18 +39,19 @@ use PPIx::Regexp::Token::Recursion		();
 use PPIx::Regexp::Token::Structure		();
 use PPIx::Regexp::Token::Unknown		();
 use PPIx::Regexp::Token::Whitespace		();
+use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.005';
+our $VERSION = '0.021';
 
 {
-    # Names of classes containing tokenization machinery. There are no
+    # Names of classes containing tokenization machinery. There are few
     # known ordering requirements, since each class recognizes its own,
     # and I have tried to prevent overlap. Absent such constraints, the
     # order is in percieved frequency of acceptance, to keep the search
     # as short as possible. If I were conscientious I would gather
     # statistics on this.
-    my @classes = (
+    my @classes = (	# TODO make readonly when acceptable way appears
 	'PPIx::Regexp::Token::Literal',
 	'PPIx::Regexp::Token::Interpolation',
 	'PPIx::Regexp::Token::Control',			# Note 1
@@ -161,12 +165,13 @@ our $VERSION = '0.005';
 	    mode => 'init',	# Initialize
 	    modifiers => [{}],	# Modifier hash.
 	    pending => [],	# Tokens made but not returned.
-	    prior => $TOKEN_UNKNOWN,	# Prior significant token.
+	    prior => TOKEN_UNKNOWN,	# Prior significant token.
 	    source => $re,	# The object we were initialized with.
-	    trace => $args{trace} || 0,
+	    trace => __PACKAGE__->_defined_or(
+		$args{trace}, $ENV{PPIX_REGEXP_TOKENIZER_TRACE}, 0 ),
 	};
 
-	if ( _INSTANCE( $re, 'PPI::Element' ) ) {
+	if ( __instance( $re, 'PPI::Element' ) ) {
 	    $self->{content} = $re->content();
 	} elsif ( ref $re ) {
 	    $errstr = ref( $re ) . ' not supported';
@@ -181,6 +186,9 @@ our $VERSION = '0.005';
 
 	$self->{cursor_limit} = length $self->{content};
 
+	$self->{trace}
+	    and warn "\ntokenizing '$self->{content}'\n";
+
 	return $self;
     }
 
@@ -238,9 +246,9 @@ sub failures {
 }
 
 sub find_matching_delimiter {
-    my ( $self, $start ) = @_;
+    my ( $self ) = @_;
     $self->{cursor_curr} ||= 0;
-    defined $start or $start = substr
+    my $start = substr
 	$self->{content},
 	$self->{cursor_curr},
 	1;
@@ -252,7 +260,7 @@ sub find_matching_delimiter {
 
     while ( ++$inx < $self->{cursor_limit} ) {
 	my $char = substr $self->{content}, $inx, 1;
-	if ( $char eq '\\' ) {
+	if ( $char eq '\\' && $finish ne '\\' ) {
 	    ++$inx;
 	} elsif ( $bracketed && $char eq $start ) {
 	    ++$nest;
@@ -291,7 +299,15 @@ sub find_regexp {
     $self->{match} = shift @capture;
     $self->{capture} = \@capture;
 
-    return wantarray ? ( $-[0], $+[0] ) : $+[0];
+    # The following circumlocution seems to be needed under Perl 5.13.0
+    # for reasons I do not fathom -- at least in the case where
+    # wantarray is false. RT 56864 details the symptoms, which I was
+    # never able to reproduce outside Perl::Critic. But returning $+[0]
+    # directly, the value could transmogrify between here and the
+    # calling module.
+##  my @data = ( $-[0], $+[0] );
+##  return wantarray ? @data : $data[1];
+    return wantarray ? ( $-[0] + 0, $+[0] + 0 ) : $+[0] + 0;
 }
 
 sub get_token {
@@ -340,10 +356,10 @@ sub make_token {
     "cursor_limit = $self->{cursor_limit}\n";
     my $token = $class->_new( $content ) or return;
     $token->significant() and $self->{expect} = undef;
-    $class eq $TOKEN_UNKNOWN and $self->{failures}++;
-
     $token->__PPIX_TOKEN__post_make( $self, $arg );
 
+    $token->isa( TOKEN_UNKNOWN ) and $self->{failures}++;
+
     $self->{cursor_curr} += $length;
     $self->{find} = undef;
     $self->{match} = undef;
@@ -364,6 +380,11 @@ sub make_token {
     return $token;
 }
 
+sub match {
+    my ( $self ) = @_;
+    return $self->{match};
+}
+
 sub modifier {
     my ( $self, $modifier ) = @_;
     return $self->{modifiers}[-1]{$modifier};
@@ -379,24 +400,13 @@ sub modifier_duplicate {
 sub modifier_modify {
     my ( $self, %args ) = @_;
 
-    # Get the current modifiers
-    my %mods = %{ $self->{modifiers}[-1] };
+    # Modifier code is centralized in PPIx::Regexp::Token::Modifier
+    $self->{modifiers}[-1] =
+	PPIx::Regexp::Token::Modifier::__PPIX_TOKENIZER__modifier_modify(
+	$self->{modifiers}[-1], \%args );
 
-    # Update the values
-    while ( my ( $key, $val ) = each %args ) {
-	if ( $val ) {
-	    $mods{$key} = $val;
-	} else {
-	    delete $mods{$key};
-	}
-    }
-
-    # Replace the modifiers (rather than simply changing them). We do it
-    # this way because of the possibility we may want to carry the
-    # current modifier value with the token so that the old object (now
-    # abandoned) keeps its value.
-    $self->{modifiers}[-1] = \%mods;
     return;
+
 }
 
 sub modifier_pop {
@@ -423,14 +433,6 @@ sub next_token {
 	    $self->{cursor_limit}++;
 	}
 
-	my $handler = '__PPIX_TOKENIZER__' . $self->{mode};
-
-	my $character = substr(
-	    $self->{content},
-	    $self->{cursor_curr},
-	    1
-	);
-
 	if ( my @tokens = $self->get_token() ) {
 	    push @{ $self->{pending} }, @tokens;
 	    redo;
@@ -503,10 +505,11 @@ sub __PPIX_TOKENIZER__init {
     my ( $class, $tokenizer, $character ) = @_;
 
     $tokenizer->{mode} = 'kaput';
-    $tokenizer->{content} =~ m/ ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
+    $tokenizer->{content} =~ m/ \A ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
 	or return $tokenizer->make_token(
-	    length( $tokenizer->{content} ), $TOKEN_UNKNOWN );
-    my ( $type, $white, $delim ) = ( $1, $2, $3 );
+	    length( $tokenizer->{content} ), TOKEN_UNKNOWN );
+#   my ( $type, $white, $delim ) = ( $1, $2, $3 );
+    my ( $type, $white ) = ( $1, $2 );
     defined $type or $type = '';
     $tokenizer->{type} = $type;
 
@@ -517,12 +520,15 @@ sub __PPIX_TOKENIZER__init {
 	and push @tokens, $tokenizer->make_token( length $white,
 	'PPIx::Regexp::Token::Whitespace' );
 
+    $tokenizer->{modifiers} = [ {} ];
     if ( $tokenizer->{content} =~ m/ ( [[:lower:]]* ) \s* \z /smx ) {
-	$tokenizer->{cursor_limit} -= length( $1 );
-	$tokenizer->{modifiers} =
-	    [ { map { $_ => 1 } split qr{}smx, $1 } ];
-    } else {
-	$tokenizer->{modifiers} = [ {} ];
+	local $_ = $1;
+	$tokenizer->{cursor_limit} -= length $_;
+	# Can't use a split() here, because we need to distinguish
+	# between s/.../.../e and s/.../.../ee.
+	while ( m/ ( ( . ) \2* ) /smxg ) {
+	    $tokenizer->{modifiers}[0]{$1} = 1;
+	}
     }
     $tokenizer->{cursor_modifiers} = $tokenizer->{cursor_limit};
 
@@ -585,11 +591,11 @@ sub __PPIX_TOKEN_FALLBACK__regexp {
     if ( $character eq '\\'
 	&& $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr} > 1
     ) {
-	return $tokenizer->make_token( 2, $TOKEN_LITERAL );
+	return $tokenizer->make_token( 2, TOKEN_LITERAL );
     }
 
     # Any normal character is unknown.
-    return $tokenizer->make_token( 1, $TOKEN_UNKNOWN );
+    return $tokenizer->make_token( 1, TOKEN_UNKNOWN );
 }
 
 sub __PPIX_TOKEN_FALLBACK__repl {
@@ -600,13 +606,13 @@ sub __PPIX_TOKEN_FALLBACK__repl {
 	&& defined ( my $next = $tokenizer->peek( 1 ) ) ) {
 
 	if ( $tokenizer->interpolates() || $next eq q<'> || $next eq '\\' ) {
-	    return $tokenizer->make_token( 2, $TOKEN_LITERAL );
+	    return $tokenizer->make_token( 2, TOKEN_LITERAL );
 	}
-	return $tokenizer->make_token( 1, $TOKEN_LITERAL );
+	return $tokenizer->make_token( 1, TOKEN_LITERAL );
     }
 
     # So is any normal character.
-    return $tokenizer->make_token( 1, $TOKEN_LITERAL );
+    return $tokenizer->make_token( 1, TOKEN_LITERAL );
 }
 
 sub __PPIX_TOKENIZER__finish {
@@ -660,7 +666,9 @@ sub __PPIX_TOKENIZER__finish {
 	    # trailing delimiter and modifiers, and return it all.
 	    push @tokens, $tokenizer->make_token(
 		$tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
-		'PPIx::Regexp::Token::Code' );
+		'PPIx::Regexp::Token::Code',
+		{ perl_version_introduced => MINIMUM_PERL },
+	    );
 	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
 	    push @tokens, $tokenizer->make_token( 1,
 		'PPIx::Regexp::Token::Delimiter' );
@@ -735,6 +743,10 @@ Specifying a positive value for this option causes a trace of the
 tokenization. This option is unsupported in the sense that the author
 reserves the right to alter it without notice.
 
+If this option is unspecified, the value comes from environment variable
+C<PPIX_REGEXP_TOKENIZER_TRACE> (see L</ENVIRONMENT VARIABLES>). If this
+environment variable does not exist, the default is 0.
+
 =back
 
 Undocumented options are unsupported.
@@ -899,6 +911,16 @@ character at the current position in the content string. If the
 delimiter is an opening bracket of some sort, bracket nesting will be
 taken into account.
 
+When searching for the matching delimiter, the back slash character is
+considered to escape the following character, so back-slashed delimiters
+will be ignored. No other quoting mechanisms are recognized, though, so
+delimiters inside quotes still count. This is actually the way Perl
+works, as
+
+ $ perl -e 'qr<(?{ print "}" })>'
+
+demonstrates.
+
 This method returns the offset from the current position in the content
 string to the matching delimiter (which will always be positive), or
 undef if no match can be found.
@@ -944,6 +966,18 @@ If the given length would include characters past the end of the string
 being tokenized, the length is reduced appropriately. If this means a
 token with no characters, nothing is returned.
 
+=head2 match
+
+ if ( $tokenizer->find_regexp( qr{ \A \w+ }smx ) ) {
+     print $tokenizer->match(), "\n";
+ }
+
+This method returns the string matched by the previous call to
+L</find_regexp>.
+
+The match is set to C<undef> by L</make_token>, as well as by another
+call to L</find_regexp>.
+
 =head2 modifier_duplicate
 
  $tokenizer->modifier_duplicate();
@@ -1007,6 +1041,17 @@ the method name will be passed to the method.
 Because this method is designed to be used within the tokenizing system,
 it will die horribly if the named method does not exist.
 
+=head1 ENVIRONMENT VARIABLES
+
+A tokenizer trace can be requested by setting environment variable
+PPIX_REGEXP_TOKENIZER_TRACE to a numeric value other than 0. Use of this
+environment variable is unsupported in the same sense that the C<trace>
+option of L</new> is unsupported. Explicitly specifying the C<trace>
+option to L</new> overrides the environment variable.
+
+The real reason this is documented is to give the user a way to
+troubleshoot funny output from the tokenizer.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
@@ -1018,7 +1063,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
